%% Preliminary plot

set(0,'defaulttextinterpreter','latex')
close all

load eta.mat
load psi_d.mat
load nu_hat.mat
load u_d.mat

N = length(eta(4,:));

psi_w = [];

for i = 2:N
    if abs(eta(4,i)-eta(4,i-1)) > 150*deg2rad
        psi_w(i) = nan;
    else
        psi_w(i) = eta(4,i);
    end
end

for i = 2:N
    if psi_w(i) < -120*deg2rad
        psi_w(i) = psi_w(i) + 2*pi;
    else
        psi_w(i) = psi_w(i);
    end
end

speed = sqrt(nu_hat(2,:).^2+nu_hat(3,:).^2);


%% Heading
figure(1)
subplot(2,1,1)
plot(eta(1,:),psi_w*rad2deg,eta(1,:),psi_d(2,:)*rad2deg)
legend('$\psi$','$\psi_d$')
ylabel('Heading [deg]')
xlabel('Time [s]')
title('$\psi$ versus $\psi_d$')
axis([0 100 -200 300])
grid on
subplot(2,1,2)
plot(nu_hat(1,:),speed,u_d(1,:),u_d(2,:))
legend('$u$','$u_d$')
axis([0 100 -0.2 1.4])
ylabel('Surge velocity [m/s]')
xlabel('Time [s]')
title('$u$ vs $u_d$')
grid on
saveas(figure(1),'psi_u','epsc')

%% Surge Velocity
%figure(2)
%
%saveas(figure(2),'u_vs_u_d.eps','epsc')

%% WP 
figure(5)
plot(WP_data(2,1),WP_data(1,1),'o',WP_data(2,2),WP_data(1,2),'o',WP_data(2,3),WP_data(1,3),'o',WP_data(2,4),WP_data(1,4),'o',WP_data(2,5),WP_data(1,5),'o','markeredgecolor','k','markerfacecolor','r','markersize',10)
hold on
line([WP_data(2,2),WP_data(2,1)],[WP_data(1,2),WP_data(1,1)])
line([WP_data(2,3),WP_data(2,2)],[WP_data(1,3),WP_data(1,2)])
line([WP_data(2,4),WP_data(2,3)],[WP_data(1,4),WP_data(1,3)])
line([WP_data(2,5),WP_data(2,4)],[WP_data(1,5),WP_data(1,4)])
legend('WP')
axis([0 30 -8 6])
xlabel('East [m]')
ylabel('North [m]')
title('Waypoints')
grid on
saveas(figure(5),'heading_WP.eps','epsc')

%% North East Plot

X = eta(2,:);
Y = eta(3,:);
PSI = psi_d(2,:);
tsamp = h;
tstart = 0;
tstop = t_stop;
track = 0;

L = 1;
dec = 5*tstop;
 
X_m = eta(2,:);
Y_m = eta(3,:);
PSI_m = eta(4,:);
 
 
figure(4)
hold on
%psiTemp=atan2(WP(2,2)-WP(2,1),WP(1,2)-WP(1,1));
 
   % siz=size(WP);
   
 
    plot(Y_m, X_m,'r')
    plot(Y,X,'k')
 
%for ii=1:(siz(2)-1)
%       plot([WP(2,ii), WP(2,ii+1)], [WP(1,ii), WP(1,ii+1)], 'g+')
% end
tnow=tstart;
for now=1:dec:length(X_m)
    
    tmpR=[cos(PSI_m(now)) -sin(PSI_m(now)); sin(PSI_m(now)) cos(PSI_m(now))];
    boat = tmpR*[L/2 .9*L/2 .5*L/2 -L/2 -L/2 .5*L/2 .9*L/2 L/2; 
              0 L/10 L/3 L/3 -L/3 -L/3 -L/10 0];
    plot(Y_m(now)+boat(2,:),X_m(now)+boat(1,:),'r');
    patch(Y_m(now)+boat(2,:),X_m(now)+boat(1,:),'r');
    
    tnow=tnow+tsamp*dec;
end
 
 
 
for now=1:dec:length(X)
    
    tmpR=[cos(PSI(now)) -sin(PSI(now)); sin(PSI(now)) cos(PSI(now))];
    boat = tmpR*[L/2 .9*L/2 .5*L/2 -L/2 -L/2 .5*L/2 .9*L/2 L/2; 
              0 L/10 L/3 L/3 -L/3 -L/3 -L/10 0];
    plot(Y(now)+boat(2,:),X(now)+boat(1,:),'r');
    patch(Y(now)+boat(2,:),X(now)+boat(1,:),'r');
    
    tnow=tnow+tsamp*dec;
end
 
hold on

plot(WP_data(2,1),WP_data(1,1),'o',WP_data(2,2),WP_data(1,2),'o',WP_data(2,3),WP_data(1,3),'o',WP_data(2,4),WP_data(1,4),'o',WP_data(2,5),WP_data(1,5),'o','markeredgecolor','k','markerfacecolor','r','markersize',5)

title('North East position')
xlabel('East [m]')
ylabel('North [m]')
grid on
hold off
axis equal
saveas(figure(4),'NE.eps','epsc')