load eta.mat
load nu.mat
load nu_d.mat
load zigzag.mat

set(0,'defaulttextinterpreter','latex')

U = sqrt(nu(2,:).^2+nu(3,:).^2);

%% Figure 1: zig-zag manuever
figure(1)
subplot(2,1,1)
plot(zigzag(1,:),zigzag(2,:),zigzag(1,:),zigzag(3,:));
grid on
xlabel('Time [s]')
ylabel('Degrees [deg]')
title('Zig-zag maneuver')
legend('$\delta$','$\psi$')
subplot(2,1,2)
plot(nu(1,:),U);
xlabel('Time [s]')
ylabel('Speed [m/s]')
title('CSEI speed')
grid on
saveas(figure(1),'zigzag.eps','epsc')

%% Figure 2: speed

U = sqrt(nu(2,:).^2+nu(3,:).^2);
figure(2)
plot(nu(1,:),U);
xlabel('Time [s]')
ylabel('Speed [m/s]')
title('CSEI speed')
grid on

%% Figure 3: yaw rate

figure(3)
subplot(2,1,1)
plot(nu(1,:),nu(3,:));
xlabel('Time [s]')
ylabel('Yaw rate [rad/s]')
grid on
title('Yaw rate CSEI')
subplot(2,1,2)
plot(nu_d(1,:),nu_d(3,:));
xlabel('Time [s]')
ylabel('Yaw acceleration [rad/s$^2$]')
grid on
title('$\dot{r}$ for CSEI')
saveas(figure(3),'yaw_yaw_rate_zigzag.eps','epsc')

%% Figure 4: yaw acceleration

figure(4)
plot(nu_d(1,:),nu_d(3,:));
xlabel('Time [s]')
ylabel('Yaw acceleration [rad/s$^2$]')
grid on
title('$\dot{r}$ for CSEI')

%% Figure 5: Nomoto time constant

r = 0.1495;
delta = 20*pi/180;
K = r/delta;

T = (K.*zigzag(2,:)-nu(3,:))./nu_d(3,:);

n = length(T);

T_max = max(abs(nu_d(3,:)));

T_samp = [];

for i = 2:n
    if abs(T(i)-T(i-1)) >= 1000
        T(i) = 0;
    else
        T(i) = T(i);
    end
    
    if abs(T(i)) >= 0.01*T_max;
        T_samp(i) = T(i);
    else
        T_samp(i) = 0;
    end
end

figure(5)
plot(nu(1,:),T)
xlim([100 330])
xlabel('Time [s]')
ylabel('Time constant [-]')
grid on
title('Nomoto time constant')

T_tild = mean(T);

%% Figure 6: Nomoto time constant II

T_2 = -nu(1,:)./(log(1-nu(3,:)./(K*delta)));
figure(6)
plot(nu(1,:),T_samp)
xlim([100 330])
xlabel('Time [s]')
ylabel('Time constant [-]')
grid on
title('Nomoto time constant II')

%% Curvefit

x0 = [1 1]
x = zeros(7,1);

nu(3,:) = nu(3,:)*180/pi;

F = inline('x(2)*pi/9*(1-exp(-nu(1,:)*x(1)))','x','nu(1,:)')
x = lsqcurvefit(F,x0,nu(1,:),nu(3,:))

figure(7)
plot(nu(1,:),nu(3,:),'g',nu(1,:),x(2)*pi/9*(1-exp(-nu(1,:)*x(1))),'r')
