%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%                                                                     %%%
%%%                 Neptunus 3DOF simulation model                      %%%
%%%                                                                     %%%
%%%                 Written by: Fredrik Sandved, 2015                   %%%
%%%                                                                     %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clear all
close all
clc

% Initialize parameters

neptunus3_DOF

% Initial settings for simulation

deg2rad                     =               pi/180;                        % Transforms degrees to radians
rad2deg                     =               180/pi;                        % Transforms radians to degrees

x_0                         =               0;                             % Initial x position
y_0                         =               0;                             % Initial y position
psi_0                       =               90;                            % Initial heading

nu_init                     =               [0 0 0]';                      % Initial velocities

eta_init                    =               [x_0 y_0 psi_0*deg2rad]';      % Initial position


% Run time and step size

t_start                     =               0;                             % Start time simulation

t_stop                      =               100;                           % End time simulation

h                           =               0.01;                          % Stepsize

% Current parameters

mu                          =               0.01;                          % Gauss Markov constant

beta_c                      =               pi;                            % Current direction

V_max                       =               0.02;                          % Maximum current velocity

V_min                       =               0.001;                         % Minimum current velocity

V_c_mean                    =               (V_max+V_min)/2;               % Mean current velocity

u_in                        =               [1 1 0];                       % Thruster input

% Run simulation

sim('neptunus_LOS.slx');

% Plot file

plot_Neptunus