%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%                                                                     %%%
%%%                         Parameters for CSEI                         %%%
%%%                         Initialization file                         %%%
%%%                                                                     %%%
%%%                 Written by: Fredrik Sandved, 2015                   %%%
%%%                                                                     %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

deg2rad             =                           pi/180;                    % Transforms degrees to radians

m                   =                           14.790;                    % Mass of CSEI
I_z                 =                           1.760;                     % Inertia in yaw
x_g                 =                           0.0375;                    % CO to CG in x-direction

M_RB                =                           [m     0      0;           % Rigid body mass matrix
                                                 0     m    m*x_g;
                                                 0   m*x_g   I_z];
    
M_A                 =                           [2  0  0;                  % Added mass matrix
                                                 0 10  0;
                                                 0  0  1];
    
D_L                 =                           [0.655  0         0;       % Linear damping matrix
                                                 0     1.330      0;
                                                 0      0     1.900];
    
D_NL                =                           [-0.355  0       0;        % Non-linear damping coefficients
                                                  0    2.776 0.845;
                                                  0    0.805 0.750];
    
l_VSP               =                           -0.4575;                   % Length from CO to VSP in x-direction
l_BT                =                           0.3875;                    % Length from CO bow thruster in x-direction

T                   =                           [1    0     0;             % Thruster mapping matrix
                                                 0    1     1;
                                                 0 l_VSP l_BT];
 
F_max_VSP           =                           1.165;                     % Saturation VSP
F_max_BT            =                           2.629;                     % Saturation bow thruster

K                   =                           [F_max_VSP   0  0;         % Thruster coefficient matrix
                                                  0   F_max_VSP 0;
                                                  0    0 F_max_BT];

 
 tau                =                           T*K;                       % Thruster allocation
