%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%                                                                     %%%
%%%                 Plot file maneuvering control system                %%%
%%%                                                                     %%%
%%%                 Written by: Fredrik Sandved, 2015                   %%%
%%%                                                                     %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

close all

load eta.mat
load eta_d.mat
load nu_r.mat
load u_d_t.mat
load s_dot.mat
load v_s.mat
load s.mat


set(0,'defaulttextinterpreter','latex')

r2d = 180/pi;

u = sqrt(nu_r(2,:).^2+nu_r(3,:).^2);

e_eta = eta - eta_d;

x_start = 1;
x_stop = max(eta(1,:)) - 1;

max_xyz = round(max(abs([min(eta(2,:)) min(eta(3,:)) max(eta(2,:))...
    max(eta(3,:)) min(eta(4,:)) max(eta(4,:))] ))) + 1;

min_xyz = -max_xyz;

max_xy = round(max(abs([min(eta(2,:)) min(eta(3,:)) max(eta(2,:))...
    max(eta(3,:))])))+ 1;
min_xy = -max_xy;

smp = 500;          % Sample for plots of squares.


%% North - East plot 

figure(1)
XX= eta(2,x_start*100:x_stop*100);
YY = eta(3,x_start*100:x_stop*100);
PSIPSI = eta(4,x_start*100:x_stop*100);
max_xy = round(max(abs([min(XX) min(YY) max(XX) max(YY)])))+ 1;
min_xy = -max_xy;
plot(YY,XX)
hold on
plot(eta_d(3,:),eta_d(2,:),'r');
hold on
axis([min_xy max_xy min_xy max_xy])
grid on
title('North East plot')
xlabel('y [m]'), ylabel('x [m]')
legend('Measured','Desired')
saveas(figure(1),'measured_vs_path.eps','epsc')


%% Desired position North East
figure(2)
subplot(3,1,1)
plot(eta(1,:),eta(2,:),eta_d(1,:),eta_d(2,:),'g')
hold on
hold off
legend('Measured','Desired')
xlabel('Time [s]'),ylabel('x [m]')
grid on
xlim([x_start x_stop])    
subplot(3,1,2)
plot(eta(1,:),eta(3,:),eta_d(1,:),eta_d(3,:),'g')
hold on
hold off
legend('Measured','Desired')
xlabel('Time [s]'),ylabel('y [m]')
grid on
xlim([x_start x_stop])    
subplot(3,1,3)
plot(eta(1,:),eta(4,:)*r2d,eta_d(1,:),eta_d(4,:)*r2d,'g')
hold on
hold off
legend('Measured','Desired')
xlabel('Time [s]'),ylabel('$\psi$ [deg]')
grid on
xlim([x_start x_stop])
saveas(figure(2),'position.eps','epsc')

%% Measured velocity vs desired velocity
figure(3)
plot(nu_r(1,:),u,u_d_t(1,:),u_d_t(2,:))
legend('$u$','$u_d$')
xlabel('Time [m/s]')
ylabel('Speed [m/s]')
title('Measured speed vs desired speed')
grid on
saveas(figure(3),'u_vs_u_d.eps','epsc')

%% speed versus differentiated path parameter
figure(4)
plot(v_s(1,:),v_s(2,:),s_dot(1,:),s_dot(2,:))
legend('$v_s$','$\dot{s}$')
xlabel('Time [s]')
ylabel('Speed [m/s]')
title('Speed assignment')
axis([0 t_stop -0.2 0.2])
grid on
saveas(figure(4),'speedass.eps','epsc')


%% Path parameter plot

figure(5)
plot(s(1,:),s(2,:))
hold off
legend('$s$')
title('Path parameter')
xlabel('Time [s]')
ylabel('$s(t)$')
grid on
saveas(figure(5),'s.eps','epsc')

%% North East Plot



XX= eta(2,x_start*100:x_stop*100);
YY = eta(3,x_start*100:x_stop*100);
PSIPSI = eta(4,x_start*100:x_stop*100);
max_xy = round(max(abs([min(XX) min(YY) max(XX) max(YY)])))+ 1;
min_xy = -max_xy;
axis([min_xy max_xy min_xy max_xy])

X = eta_d(2,:);
Y = eta_d(3,:);
PSI = eta_d(4,:);
tsamp = 0.01;
tstart = 0;
tstop = eta_d(1,end);
track = 0;

L = 1;
dec = 5*tstop;
 
X_m = eta(2,:);
Y_m = eta(3,:);
PSI_m = eta(4,:);
 
 
figure(8)
hold on
 
    plot(Y_m, X_m,'b')
    est = plot(Y,X,'g');
 

tnow=tstart;
for now=1:dec:length(X_m)
    
    tmpR=[cos(PSI_m(now)) -sin(PSI_m(now)); sin(PSI_m(now)) cos(PSI_m(now))];
    boat = tmpR*[L/2 .9*L/2 .5*L/2 -L/2 -L/2 .5*L/2 .9*L/2 L/2; 
              0 L/10 L/3 L/3 -L/3 -L/3 -L/10 0];
    plot(Y_m(now)+boat(2,:),X_m(now)+boat(1,:),'r');
    mea = patch(Y_m(now)+boat(2,:),X_m(now)+boat(1,:),'r');
    
    tnow=tnow+tsamp*dec;
end

title('North East position')
xlabel('East [m]')
legend([est mea],'Desired','CSEI')
ylabel('North [m]')
grid on
hold off
axis equal 
saveas(figure(8),'NE.eps','epsc')