%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%                                                                     %%%
%%%                 Run file heading on WP for Neptunus                 %%%
%%%                                                                     %%%
%%%                 Written by: Fredrik Sandved, 2015                   %%%
%%%                                                                     %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clear all
close all
clc

% Initialize parameters

neptunus3_DOF

% Initial settings for simulation

deg2rad                     =               pi/180;                        % Transforms degrees to radians
rad2deg                     =               180/pi;                        % Transforms radians to degrees

x_0                         =               0;                             % Initial x position
y_0                         =               0;                             % Initial y position
psi_0                       =               90;                            % Initial heading

nu_init                     =               [0 0 0]';                      % Initial velocities

eta_init                    =               [x_0 y_0 psi_0*deg2rad]';      % Initial position


% Run time and step size

t_start                     =               0;                             % Start time simulation

t_stop                      =               100;                           % End time simulation

h                           =               0.01;                          % Stepsize

% Current parameters

mu                          =               0.01;                          % Gauss Markov constant

beta_c                      =               pi;                            % Current direction

V_max                       =               0.02;                          % Maximum current velocity

V_min                       =               0.001;                         % Minimum current velocity

V_c_mean                    =               (V_max+V_min)/2;               % Mean current velocity


WP_data_1                   =               [0 10 10 0 0 10 10 0;          % Waypoint data set 1
                                            10 10 0  0 10 10 0 0];

WP_data_2                   =               [3 4 0 -3 -1 3 4 4;            % Waypoint data set 2
                                            10 12 18 19 13 14 20 100];

WP_data_3                   =               [3 -5 -6  2 3  4;              % Waypoint data set 3
                                             3 10 15 20 25 80];

WP_data                     =               WP_data_3;                     % Waypoint set of consideration in simulation
      
R_lim                       =               0.5;                           % Circle of acceptance radius

% Guidance parameters

u_r                         =               0.5;                           % Referance velocity

omega_n                     =               0.8;                           % Natural frequency reference model

zeta                        =               1;                             % Critical damping ratio reference model

% Controller gains

K_p_u                       =               10;                            % Proportional gain surge
K_i_u                       =               1;                             % Integral gain surge

K_p_psi                     =               5;                             % Proportional gain heading
K_i_psi                     =               0.5;                           % Integral gain heading

% Run simulation

sim('neptunus_heading_WP.slx');

% Plot file

plot_heading_WP
