%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%                                                                     %%%
%%%                 Run file maneuvering control system                 %%%
%%%                                                                     %%%
%%%                 Written by: Fredrik Sandved, 2015                   %%%
%%%                                                                     %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


clear all
close all
clc

deg2rad                 =               pi/180;                            % Transforms degrees to radians
rad2deg                 =               180/pi;                            % Transforms radians to degrees

%Intialization of vehicle parameters

neptunus3_DOF

% Initialization parameters

x_0                     =               0;                                 % Init x-position
y_0                     =               0;                                 % Init y-position
psi_0                   =               0;                                 % Init heading

eta_init                =               [x_0 y_0 psi_0*deg2rad]';          % Init positons

nu_init                 =               [0 0 0]';                          % Init velocities

% Simulation parameters

t_stop                  =               400;                               % Start time
t_start                 =               0;                                 % Stop time
h                       =               0.01;                              % Stepsize

% Path parameters

x_c                     =               0;                                 % x-coordinate center of ellipsoid
y_c                     =               0;                                 % y-coordinate center of ellipsoid

r_x                     =               10;                                % x radius of ellipsoid
r_y                     =               10;                                % y radius of ellipsoid

% Control system parameters

u_d                     =               0.6;                               % Desired speed

K_p_x                   =               10;                               % Proportional gain x
K_p_y                   =               1;                                 % Proportional gain y
K_p_psi                 =               10;                                % Proportional gain heading

K_d_u                   =               1;                              % Derivative gain x
K_d_v                   =               0.2;                              % Derivative gain y
K_d_r                   =               10;                              % Derivative gain heading

K_b_u                   =               0.001;                             % Integral gain u
K_b_v                   =               0.1;                               % Integral gain v
K_b_r                   =               0.001;                             % Integral gain r

K_b                     =               diag([K_b_u,K_b_v,K_b_r]);         % Integral gain matrix

my                      =               0.0000;                             % Gradient update law gain

Delta                   =               5;                                 % Lookahead distance
% Current parameters

mu                      =               0.01;                              % Gauss Markov constant

beta_c                  =               pi;                                % Current direction

V_max                   =               0.02;                              % Maximum current velocity

V_min                   =               0.0001;                            % Minimum current velocity

V_c_mean                =               (V_max+V_min)/2;                   % Mean current velocity

% Simulation file

sim('maneuvering_nep.slx')


% Plot file

plot_Maneuvering