%% Parameters 6 DOF model for Neptunus

m                   =                       3.46;       % mass of ROV
ro                  =                       1025;
V                   =                       4.7896*10^-3;
g                   =                       9.81;
deg2rad             =                       pi/180;

x_g                 =                       0;          
y_g                 =                       0;
z_g                 =                       0;

r_g                 =                       [x_g,y_g,z_g]';     % CO to CG

x_b                 =                       0;
y_b                 =                       0; 
z_b                 =                       -0.0755;

r_b                 =                       [x_b,y_b,z_b]';


I_xx                =                       0.015402537;
I_xy                =                       0.000000178;
I_xz                =                       -0.000207337;

I_yy                =                       0.050703;
I_yx                =                       0.000000178;
I_yz                =                       0.000000006967;

I_zz                =                       0.039895;
I_zx                =                       -0.000207337;
I_zy                =                       0.00000006967;

I_g                 =                       [I_xx     I_xy    I_xz;
                                             I_yx     I_yy    I_yz;
                                             I_zx     I_zy    I_zz];

% Rigid body matrices
                                         
M_RB                =                       [m*eye(3)   -m*Smtrx(r_g);
                                             m*Smtrx(r_g)  I_g-m*Smtrx(r_g)^2];
                                         
%C_RB                =                       [m*Smtrx(omega)         -m*Smtrx(omega)*Smtrx(r_g);
                                             %m*Smtrx(r_g)*Smtrx(omega)      -Smtrx((I_g-m*Smtrx(r_g)^2)*omega)];   
                                         
% Added mass matrices
added_mass_calc                                     


M_11                =                    [M_RB(1,1)   M_RB(1,2)    M_RB(1,3);
                                          M_RB(2,1)   M_RB(2,2)    M_RB(2,3);
                                          M_RB(3,1)   M_RB(3,2)    M_RB(3,3)];
                                     
M_12                =                    [M_RB(1,4)   M_RB(1,5)    M_RB(1,6);
                                          M_RB(2,4)   M_RB(2,5)    M_RB(2,6);
                                          M_RB(3,4)   M_RB(3,5)    M_RB(3,6)];  

M_21                =                    [M_RB(4,1)   M_RB(4,2)    M_RB(4,3);
                                          M_RB(5,1)   M_RB(5,2)    M_RB(5,3);
                                          M_RB(6,1)   M_RB(6,2)    M_RB(6,3)];
                                     
M_22                =                    [M_RB(4,4)   M_RB(4,5)    M_RB(4,6);
                                          M_RB(5,4)   M_RB(5,5)    M_RB(5,6);
                                          M_RB(6,4)   M_RB(6,5)    M_RB(6,6)];
                                      
A_11                =                    [M_A_sym(1,1)   M_A_sym(1,2)    M_A_sym(1,3);
                                          M_A_sym(2,1)   M_A_sym(2,2)    M_A_sym(2,3);
                                          M_A_sym(3,1)   M_A_sym(3,2)    M_A_sym(3,3)];
                                     
A_12                =                    [M_A_sym(1,4)   M_A_sym(1,5)    M_A_sym(1,6);
                                          M_A_sym(2,4)   M_A_sym(2,5)    M_A_sym(2,6);
                                          M_A_sym(3,4)   M_A_sym(3,5)    M_A_sym(3,6)];  

A_21                =                    [M_A_sym(4,1)   M_A_sym(4,2)    M_A_sym(4,3);
                                          M_A_sym(5,1)   M_A_sym(5,2)    M_A_sym(5,3);
                                          M_A_sym(6,1)   M_A_sym(6,2)    M_A_sym(6,3)];
                                     
A_22                =                    [M_A_sym(4,4)   M_A_sym(4,5)    M_A_sym(4,6);
                                          M_A_sym(5,4)   M_A_sym(5,5)    M_A_sym(5,6);
                                          M_A_sym(6,4)   M_A_sym(6,5)    M_A_sym(6,6)];                                      
                                      
%C_A                 =                   [zeros(3)                       -Smtrx(A_11*nu_1+A_12*omega);
                                         %-Smtrx(A_11*nu_1+A_12*omega)   -Smtrx(A_21*nu_1+A_22*omega)];
                                     
% Damping matrices

D_L                 =                   diag([2.2907,4.9804,15.1897,0.0091,-0.0501,0.261]);

D_NL                =                   diag([4.0077,35.2159,10.3037,0.1913,0.4807,0.3196]);

% Restoring forces

W                   =                   m*g;

B                   =                   33.966;

g_eta_coeff         =                    [(W-B);
                                         -(W-B)
                                         -(W-B)
                                         -(y_g*W-y_b*B) + (z_g*W-z_b*B)
                                         (z_g*W-z_b*B) + (x_g*W-x_b*B)
                                         -(x_g*W-x_b*B) - (y_g*W-y_b*B)];
                                                                              
                                     

% Thruster allocation

l_1                 =                   -0.17996;                           % Length from CO to hor. thrusters (y-dir)                     
alpha               =                   8.9144*deg2rad;
l_2                 =                   0.04435;


T                   =                   [cos(alpha)                             cos(alpha)                0;               % Thruster allocation matrix
                                         sin(alpha)                            -sin(alpha)                0; 
                                             0                                      0                     1; 
                                             0                                      0                     0; 
                                             0                                      0                     0; 
                                         -l_1*sin(alpha)+l_2*cos(alpha) l_1*sin(alpha)-l_2*cos(alpha)     0];

K_11                =                   1;                                  % Thrust coefficient 1
K_22                =                   1;                                  % Thrust coefficient 2
K_33                =                   1;                                  % Thrust coefficient 3

K                   =                   diag([K_11, K_22, K_33]);           % Thrust coefficient matrix
