%% Plot file - TMR4555
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Written by Fredrik Sandved
%
% Date: 15.12.2014
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Purpose:
% Plot the desired plots of Neptunus
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

close all

rad2deg = 180/pi;

set(0,'defaulttextinterpreter','latex');

%% Loading of data from the simulation in Simulink

load                            eta_t.mat           % position data
load                            nu_r.mat            % velocity data
load                            nu_dot.mat          % acceleration file
load                            g_eta.mat           % restoring force file
load                            non_ld.mat          % non-linear damping file
load                            nu_c.mat            % current velocity file
load                            cor.mat             % coreolis force file

%% Figure 1: Position plot
figure(1)

subplot(3,2,1)
plot(eta_t(1,:),eta_t(2,:));
ylabel('North [m]')
xlabel('Time [s]')
title('North Position')
grid on
subplot(3,2,2)
plot(eta_t(1,:),eta_t(3,:));
ylabel('East [m]')
xlabel('Time [s]')
grid on
title('East Position')
subplot(3,2,3)
plot(eta_t(1,:),eta_t(4,:));
ylabel('Down [m]')
xlabel('Time [s]')
grid on
title('Down Position')
subplot(3,2,4)
plot(eta_t(1,:),eta_t(5,:)*rad2deg);
ylabel('Roll [deg]')
xlabel('Time [s]')
grid on
title('Roll motion')
subplot(3,2,5)
plot(eta_t(1,:),eta_t(6,:)*rad2deg);
ylabel('Pitch [deg]')
grid on
xlabel('Time [s]')
title('Pitch motion')
subplot(3,2,6)
plot(eta_t(1,:),eta_t(7,:)*rad2deg);
ylabel('Yaw [deg]')
xlabel('Time [s]')
grid on
title('Yaw motion')
saveas(figure(1),'position.png')
saveas(figure(1),'position.eps','epsc')

%% Figure 2: Velocity plot

figure(2)
subplot(3,2,1)
plot(nu_r(1,:),nu_r(2,:));
grid on
ylabel('Velocity [m/s]')
xlabel('Time [s]')
title('Velocity in Surge')
subplot(3,2,2)
plot(nu_r(1,:),nu_r(3,:));
ylabel('Velocity [m/s]')
grid on
xlabel('Time [s]')
title('Velocity in Sway')
subplot(3,2,3)
plot(nu_r(1,:),nu_r(4,:));
ylabel('Velocity [m/s]')
xlabel('Time [s]')
grid on
title('Velocity in Heave')
subplot(3,2,4)
plot(nu_r(1,:),nu_r(5,:));
ylabel('Rate [rad/s]')
xlabel('Time [s]')
grid on
title('Roll Rate')
subplot(3,2,5)
plot(nu_r(1,:),nu_r(6,:));
ylabel('Rate [rad/s]')
xlabel('Time [s]')
grid on
title('Pitch Rate')
subplot(3,2,6)
plot(nu_r(1,:),nu_r(7,:));
ylabel('Rate [rad/s]')
xlabel('Time [s]')
title('Yaw Rate')
grid on
saveas(figure(2),'velocities.png')
saveas(figure(2),'velocities.eps','epsc')

%% Figure 3: Acceleration plot

figure(3)
subplot(3,2,1)
plot(nu_dot(1,:),nu_dot(2,:));
ylabel('Acceleration [m/s^2]')
xlabel('Time [s]')
grid on
title('Accelerations in surge')
subplot(3,2,2)
plot(nu_dot(1,:),nu_dot(3,:));
ylabel('Acceleration [m/s^2]')
xlabel('Time [s]')
grid on
title('Accelerations in sway')
subplot(3,2,3)
plot(nu_dot(1,:),nu_dot(4,:));
ylabel('Acceleration [m/s^2]')
xlabel('Time [s]')
grid on
title('Accelerations in heave')
subplot(3,2,4)
plot(nu_dot(1,:),nu_dot(5,:));
ylabel('Acceleration [rad/s^2]')
xlabel('Time [s]')
grid on
title('Accelerations in roll')
subplot(3,2,5)
plot(nu_dot(1,:),nu_dot(6,:));
ylabel('Acceleration [rad/s^2]')
xlabel('Time [s]')
grid on
title('Accelerations in pitch')
subplot(3,2,6)
plot(nu_dot(1,:),nu_dot(7,:));
title('Accelerations in yaw')
ylabel('Acceleration [rad/s^2]')
xlabel('Time [s]')
grid on
saveas(figure(3),'acceleration.png')
saveas(figure(3),'acceleration.eps','epsc')

%% Figure 4: Restoring force plot

figure(4)
subplot(3,2,1)
plot(g_e(1,:),g_e(2,:))
title('Restoring in surge')
ylabel('Force [N]')
xlabel('Time [s]')
grid on
subplot(3,2,2)
plot(g_e(1,:),g_e(3,:))
title('Restoring in sway')
ylabel('Force [N]')
xlabel('Time [s]')
grid on
subplot(3,2,3)
plot(g_e(1,:),g_e(4,:))
title('Restoring in heave')
ylabel('Force [N]')
grid on
xlabel('Time [s]')
subplot(3,2,4)
plot(g_e(1,:),g_e(5,:))
title('Restoring in roll')
ylabel('Moment [Nm]')
grid on
xlabel('Time [s]')
subplot(3,2,5)
plot(g_e(1,:),g_e(6,:))
title('Restoring in pitch')
ylabel('Moment [Nm]')
xlabel('Time [s]')
grid on
subplot(3,2,6)
plot(g_e(1,:),g_e(7,:))
title('Restoring in yaw')
ylabel('Moment [Nm]')
grid on
xlabel('Time [s]')
saveas(figure(4),'restoring.png')
saveas(figure(4),'restoring.eps','epsc')

%% Figure 5: Coreolis force plot

figure(5)
subplot(3,2,1)
plot(cor(1,:),cor(2,:))
title('Coreolis force in surge')
ylabel('Force [N]')
grid on
xlabel('Time [s]')
subplot(3,2,2)
plot(cor(1,:),cor(3,:))
title('Coreolis force in sway')
ylabel('Force [N]')
grid on
xlabel('Time [s]')
subplot(3,2,3)
plot(cor(1,:),cor(4,:))
title('Coreolis force in heave')
ylabel('Force [N]')
grid on
xlabel('Time [s]')
subplot(3,2,4)
plot(cor(1,:),cor(5,:))
title('Coreolis moment in roll')
ylabel('Moment [Nm]')
grid on
xlabel('Time [s]')
subplot(3,2,5)
plot(cor(1,:),cor(6,:))
title('Coreolis moment in pitch')
ylabel('Moment [Nm]')
xlabel('Time [s]')
subplot(3,2,6)
plot(cor(1,:),cor(7,:))
title('Coreolis moment in yaw')
ylabel('Moment [Nm]')
grid on
xlabel('Time [s]')
saveas(figure(5),'coreolis.png')
saveas(figure(5),'coreolis.eps','epsc')

%% Figure 6: Non-linear damping plot

figure(6)
subplot(3,2,1)
plot(non_ld(1,:),non_ld(2,:))
title('Non linear damping in surge')
ylabel('Force [N]')
grid on
xlabel('Time [s]')
subplot(3,2,2)
plot(non_ld(1,:),non_ld(3,:))
title('Non linear damping in sway')
ylabel('Force [N]')
xlabel('Time [s]')
grid on
subplot(3,2,3)
plot(non_ld(1,:),non_ld(4,:))
title('Non linear damping in heave')
ylabel('Force [N]')
grid on
xlabel('Time [s]')
subplot(3,2,4)
plot(non_ld(1,:),non_ld(5,:))
title('Non linear damping in roll')
ylabel('Moment [Nm]')
grid on
xlabel('Time [s]')
subplot(3,2,5)
plot(non_ld(1,:),non_ld(6,:))
title('Non linear damping in pitch')
ylabel('Moment [Nm]')
grid on
xlabel('Time [s]')
subplot(3,2,6)
plot(non_ld(1,:),non_ld(7,:))
title('Non linear damping in yaw')
ylabel('Moment [Nm]')
grid on
xlabel('Time [s]')
saveas(figure(6),'nl_damping.png')
saveas(figure(6),'nl_damping.eps','epsc')

%% Figure 7: Current velocity plot

figure(7)
subplot(2,1,1)
plot(nu_cout(1,:),nu_cout(2,:))
title('Current velocities surge')
ylabel('Velocity [m/s]')
grid on
xlabel('Time [s]')
subplot(2,1,2)
plot(nu_cout(1,:),nu_cout(3,:))
title('Current velocities sway')
ylabel('Velocity [m/s]')
grid on
xlabel('Time [s]')
saveas(figure(7),'current_vel.png')
saveas(figure(7),'current_vel.eps','epsc')


%% Figure 10: North East Plot

X =         eta_t(2,:);         % setting the North Position
Y =         eta_t(3,:);         % setting the East Position
PSI =       eta_t(7,:);         % setting the Yaw Angle

tsamp =     h;                  % Sample time
tstart =    0;                  % Starting time
tstop =     t_stop-t_start;           % End time

L =         0.4;                % Length of ROV
dec =       20*tstop;            % Stepsize


figure(9)
hold on

plot(Y,X,'b')


tnow=       tstart;             % First step in loop

for now=1:dec:length(X)
    % Generating boats in plot
    tmpR=[cos(PSI(now)) -sin(PSI(now)); sin(PSI(now)) cos(PSI(now))];
    boat = tmpR*[L/2 .9*L/2 .5*L/2 -L/2 -L/2 .5*L/2 .9*L/2 L/2; 
              0 L/10 L/3 L/3 -L/3 -L/3 -L/10 0];
    plot(Y(now)+boat(2,:),X(now)+boat(1,:),'y');
    patch(Y(now)+boat(2,:),X(now)+boat(1,:),'y');
    
    tnow=tnow+tsamp*dec;
end
  
xlabel('East [m]')
ylabel('North [m]')
grid on
hold off
axis equal
saveas(figure(9),'NE.png')
saveas(figure(9),'NE.eps','epsc')